CameraFrameRotation enum

Optional rotation applied after colour conversion. Detector packages map this to an opencv ROTATE_* code.

Inheritance
Available extensions

Values

cw90 → const CameraFrameRotation

Rotate 90° clockwise.

cw180 → const CameraFrameRotation

Rotate 180°.

cw270 → const CameraFrameRotation

Rotate 90° counter-clockwise (270° clockwise).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CameraFrameRotation>
A constant List of the values in this enum, in order of their declaration.